/*! \file
	\brief Configuration rules for the YAVTI project

	If a rule is broken a compile \#error occurs with an appropriate message
*/
/*
	MRU 110912
	110912 Removed rules for SW_OSD, MAX7456OSD and DOGMDISPLAY
	110113	Added tests for TICKSPERSEC and TIMERFREQ
*/
#include "SIMRCV.h"
#include "config.h"
#ifndef _CONFIG_RULES_H_
	#define _CONFIG_RULES_H_

/* Do not change the following part, it tests the config */

/* Define at least one of GPS and LWTIME */
#if (!defined GPS) && (!defined LWTIME)
	 #error Define one or both of GPS or LWTIME
#endif

#if ((HARDWARE == SVEN_DEFS) && (VTIDEVICE == MAX7456OSD))
	#error No MAX7456 in Sven hardware
#endif

#if ((HARDWARE == SVEN_DEFS) && (defined DOGMDISPLAY))
	#error No DOGMDISPLAY in Sven hardware
#endif

#if (HARDWARE != SVEN_DEFS)
	#define INIT_MUXS0			/* These only in Sven's HW */
	#define INIT_OE
#endif /* !SVEN_DEFS */

#if (VTIDEVICE == NO_OSD)
	#define INIT_VSYNC			/* Not needed if no VTI */
	#define INIT_CV
#endif
#if ((HARDWARE != SVEN_DEFS) && (VTIDEVICE == SW_OSD))
	#error Software OSD only available in Sven''s hardware
#endif

/* Use SPI for SW_OSD, MAX7456 and DOGM display */
#if ((VTIDEVICE != NO_OSD) || (defined DOGMDISPLAY))
	#define SPI_DEV
#endif
/* GPS must have RS232 */
#ifdef GPS
	#if (PGMFUNCTION == RECEIVER)
		#define RX_RS232
	#endif
	#if (PGMFUNCTION == SIMULATOR)
		#define TX_RS232
	#endif
#endif
#ifdef TICKSPERSEC
/* Check the timer frequencies */
	#if ((1000 % TICKSPERSEC) != 0)
		#error TICKSPERSEC must be a submultiple of 1000
	#endif
	#if ((TICKSPERSEC % TIMERFREQ) != 0)
		#error TIMERFREQ must be a submultiple of TICKSPERSEC */
	#endif
#endif /* TICKSPERSEC */

#if (defined LW_RCV) && (defined LW_SIM)
	#error Define only one or none of LW_RCV and LW_SIM
#endif

#if (!defined DCF77) && (!defined MSF) && (!defined WWVB) && (!defined JJY)
	#error Define at least one LW transmitter
#endif /* !DCF77 && !MSF && !WWVB && !JJY */

/* If RXPOLL is defined:
	As experiment run RX without interrupt to reduce jitter in the SW_OSD
	This changes the USART initialisation and runs the RX at base level
	as a task
*/
#if (PGMFUNCTION == SIMULATOR)
	#undef RXPOLL			/* Never use RXPOLL for SIMULATOR */
#endif

#if (PGMFUNCTION == RECEIVER)
	#if (VTIDEVICE == SW_OSD)
		#define RXPOLL
	#else
		#undef RXPOLL
	#endif
#endif
#endif /* _CONFIG_RULES_H_ */
